<?php

declare(strict_types=1);

namespace Workbench\App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Workbench\Database\Factories\TestModelFactory;

final class TestModel extends Model
{
    /** @use HasFactory<TestModelFactory> */
    use HasFactory;
}
