<?php

declare(strict_types=1);

use Illuminate\Support\Facades\Route;

Route::name('endpoints.')->group(fn (): array => [
    Route::get('test1', fn (): true => true)->name('test1.index'),
    Route::get('test2', fn (): true => true)->name('test2.show'),
    Route::get('test3/{id}', fn (): false => false)->name('test3.index'),
    Route::get('test4/{id}', fn (): false => false)->name('test4.show'),
]);
