<mjml>
    <mj-head>
        <mj-attributes>
            <mj-all padding="0px"></mj-all>
            <mj-text font-family="Helvetica, Arial, sans-serif" padding="0 25px" font-size="14px"></mj-text>
            <mj-class name="preheader" color="#000000" font-size="11px"></mj-class>
        </mj-attributes>
        <mj-style inline="inline">a {
            text-decoration: none !important;
            color: inherit !important;
        }</mj-style>
    </mj-head>
    <mj-body background-color="#ffffff">
        <mj-raw>@isset($image)</mj-raw>
        <mj-section padding="20px">
            <mj-column width="150px">
                <mj-image src="{{$image}}" alt="Logo" padding="0px"></mj-image>
            </mj-column>
        </mj-section>
        <mj-raw>@endisset</mj-raw>

        <mj-section background-color="#f0f0f0" padding-bottom="20px" padding-top="20px">
            <mj-column>
                <mj-text font-size="20px">{{ $title }}</mj-text>
                <mj-spacer/>
                <mj-text>@yield('content')</mj-text>
            </mj-column>
        </mj-section>

        <mj-raw>@isset($sender)</mj-raw>
        <mj-section padding="20px">
            <mj-column>
                <mj-text align="center">{{ $sender }}</mj-text>
            </mj-column>
        </mj-section>
        <mj-raw>@endisset</mj-raw>
    </mj-body>
</mjml>
