<?php

declare(strict_types=1);

namespace Tricks\LaravelTools\Data\Monitoring;

use Spatie\LaravelData\Data;

final class EndpointData extends Data
{
    public function __construct(
        public string $url,
    ) {
        //
    }
}
