<?php

declare(strict_types=1);

return [
    'frontend' => [
        /** @phpstan-ignore larastan.noEnvCallsOutsideOfConfig */
        'url' => env('BASE_URL'),
    ],

    'preview_mapping' => [
        // \App\Models\User::class => 'benutzer',
    ],

    'monitoring' => [
        'packages' => [
            'laravel/framework',
            'laravel/nova',
        ],
        'composer' => [
            /** @phpstan-ignore larastan.noEnvCallsOutsideOfConfig */
            'bin' => env('COMPOSER_BIN', 'composer'),
            /** @phpstan-ignore larastan.noEnvCallsOutsideOfConfig */
            'home' => env('COMPOSER_HOME'),
        ],
    ],
];
