<?php

declare(strict_types=1);

use function Pest\Laravel\getJson;

test('confirm api route last-updated exists', function (): void {
    $response = getJson('/api/tricks/last_updated');

    $response->assertJsonStructure([
        'data_was_updated_since_last_midnight',
        'last_updated_date',
    ]);
    $response->assertJsonFragment([
        'data_was_updated_since_last_midnight' => false,
        'last_updated_date' => null,
    ]);
});
