<?php

declare(strict_types=1);

use Illuminate\Support\Facades\Route;
use Tricks\LaravelTools\Http\Controllers\LastUpdatedController;
use Tricks\LaravelTools\Http\Controllers\MonitoringController;

Route::middleware('api')->group(fn (): array => [
    Route::get('api/tricks/monitoring', MonitoringController::class),
    Route::get('api/tricks/last_updated', LastUpdatedController::class),
]);
